@@ -16,8 +16,8 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 __author__ = 'chris'
-from pythomics.proteomics import config
 import sys
+from . import config
 
 class Chromatogram(object):
     pass
